@@ -56,8 +56,8 @@ protected:
     void paintAxisAndLines(QPainter* painter, qreal offset);
 private:
     static void appendDimension(QQmlListProperty<Dimension>* list, Dimension* dimension);
-    static int countDimensions(QQmlListProperty<Dimension>* list);
-    static Dimension* dimensionAt(QQmlListProperty<Dimension>* list, int index);
+    static qsizetype countDimensions(QQmlListProperty<Dimension>* list);
+    static Dimension* dimensionAt(QQmlListProperty<Dimension>* list, qsizetype index);
     static void clearDimensions(QQmlListProperty<Dimension>* list);
     QAbstractTableModel* m_model;
     QList<Dimension*> m_dimensions;
